@@ -9,6 +9,7 @@ OC.L10N.register(
     "Remove user from card" : "Odobrať používateľa z karty",
     "Hours" : "Hodín",
     "Minutes" : "Minút",
+    "Link to a board" : "Odkaz na nástenku",
     "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}",
     "You have created a new board {board}" : "Vytvorili ste nová nástenku {board}",
     "{user} has created a new board {board}" : "Používateľ {user} vytvoril novú nástenku {board}",
@@ -105,6 +106,8 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "Nenahral sa žiadny súbor alebo jeho veľkosť presiahla %s",
     "A kanban style project and personal management tool for Nextcloud" : "Nástroj pre projektové a osobné riadenie v štýle Kanban.",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Karty sú nástroj zacielený na osobné alebo projektové plánovanie tímov v štýle Kanban integrovaný do Nextcloud.\n\n\n- 📥 Zadávajte a usporadúvajte svoje úlohy do kariet\n- 📄 Zapisujte si dodatočné poznámky\n- 🔖 Priraďujte štítky pre ešte lepšiu organizáciu\n- 👥 Zdieľajte so svojim tímom, priateľmi alebo rodinou\n- 🚀 Dostaňte svoj projekt pod kontrolu",
+    "Select the board to link to a project" : "Vybrať nástenku na vytvorenie odkazu ku projektu",
+    "Select board" : "Vybrať nástenku",
     "Add a new stack" : "Pridať nový stoh",
     "Submit" : "Odoslať",
     "Show archived cards" : "Zobraziť archivované karty",
@@ -131,6 +134,7 @@ OC.L10N.register(
     "Timeline" : "Časová os",
     "Select users or groups to share with" : "Vyberte používateľov albo skupiny pre sprístupnenie",
     "Group" : "Skupina",
+    "Circle" : "Kruh",
     "No matching user or group found." : "Neboli nájdení vyhovujúci používatelia alebo skupiny.",
     "Loading" : "Načítavanie",
     "Edit" : "Upraviť",
